package com.takensoft.ai_lms.lms.auth.web;

import com.google.gson.Gson;
import com.google.gson.JsonObject;
import com.takensoft.ai_lms.lms.auth.dto.LoginDTO;
import com.takensoft.ai_lms.lms.auth.service.AuthService;
import com.takensoft.ai_lms.lms.auth.vo.UserVO;
import io.swagger.v3.oas.annotations.Operation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

/**
 * @author  : 방선주
 * since   : 2024.05.09
 * 사용자 관련 Controller
 */
@RestController
@RequiredArgsConstructor
@Slf4j
@RequestMapping(value="/auth")
public class AuthController {

    private final AuthService authService;

    /**
     * @author  방선주
     * @since   2024.07.12
     * param   UserVO
     * @return
     * @throws  Exception
     *
     * 사용자 등록
     */
    @PostMapping("/insertUser.json")
    @Operation(summary = "사용자 등록")
    public String insertUser(@RequestBody UserVO userVO) throws Exception {
        Gson gson = new Gson();
        JsonObject response = new JsonObject();

        try {
            int result = authService.insertUser(userVO);


            if (result == -1) {
                response.addProperty("status", "fail");
                response.addProperty("message", "동일한 계정이 존재합니다.");
                return gson.toJson(response);
            }

            response.addProperty("status", "success");
            response.addProperty("message", "사용자가 등록되었습니다.");
            return gson.toJson(response);
        } catch (Exception e) {
            response.addProperty("status", "error");
            response.addProperty("message", e.getMessage());
            return gson.toJson(response);
        }


    }

    /**
     * @author  : 박민혁
     * @since   : 2024.08.02
     * 로그인 기능
     */
    @PostMapping("/login.json")
    @Operation(summary = "사용자 로그인")
    public String login(@RequestBody LoginDTO loginDTO) {
        Gson gson = new Gson();
        JsonObject response = new JsonObject();

        try {
            String token = authService.login(loginDTO);
            response.addProperty("status", "success");
            response.addProperty("token", token);
            return gson.toJson(response);
        } catch (Exception e) {
            response.addProperty("status", "error");
            response.addProperty("message", e.getMessage());
            return gson.toJson(response);
        }
    }

    @PostMapping("/logout.json")
    @Operation(summary = "사용자 로그아웃")
    public String logout(@RequestHeader("Authorization") String token) {
        Gson gson = new Gson();
        JsonObject response = new JsonObject();

        try {
            authService.logout(token);

            response.addProperty("status", "success");
            response.addProperty("message", "성공적으로 로그아웃되었습니다.");
            return gson.toJson(response);
        } catch (Exception e) {
            response.addProperty("status", "error");
            response.addProperty("message", e.getMessage());
            return gson.toJson(response);
        }
    }

}
